package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````Y18``#0```"8@0````0`!30`(``)
M`"@`&P`:``$``'!$?```1'P``$1\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!0?```4'P```4`````$```
M`0```+A]``"XC0``N(T``)`"``"D`@``!@`````0```"````P'T``,"-``#`
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DN'T`
M`+B-``"XC0``2`(``$@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`54XC+\>OYZ4'LYM'@229&G&J6I@$
M````$`````$```!'3E4```````,````"`````````!$```!-````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$T```!.````40``
M`%4```!6````7P```&````!A`````````&,```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+(!BV^93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)N^VE<;X*<""FL:GE"CX/M)````
M```````````````````````,$@````````,`"P```````)`````````#`!8`
M)P(`````````````$@```,4!`````````````!(```#E`0`````````````2
M````E0$`````````````(@```/8"`````````````!$```"#`P``````````
M```2````$```````````````(````*0!`````````````!(````0`@``````
M```````2````MP$`````````````$@```.D``````````````!(````2`P``
M```````````1````@P(`````````````$@```$T!`````````````!(```"2
M`@`````````````2````+@(`````````````$@```(<``````````````!(`
M``!/`@`````````````2````Y```````````````$@```#L"````````````
M`!(```#8`@`````````````2``````,`````````````$@```),"````````
M`````!(```#S`0`````````````2````5@(`````````````$@```#\!````
M`````````!(```#&```````````````1````#0$`````````````$@```&,`
M`````````````!8```#/`@`````````````2````?`(`````````````$0``
M`$("`````````````!(```![`0`````````````2````H@(`````````````
M$@```&@!`````````````!(```":`@`````````````2````[`$`````````
M````$@```'0!`````````````!(```"J`@`````````````2````&P$`````
M````````$@````$``````````````"````"P`0`````````````2````R@(`
M````````````$@```#0"`````````````!(```"&`0`````````````1````
M5```````````````$@```*D!`````````````!(```"6```````````````2
M````N0(`````````````$@```&X"`````````````!(```"B````````````
M```2````-`$`````````````$@```/`"`````````````!(````!`@``````
M```````2````^@``````````````$@```$8``````````````!(```#N````
M```````````2````70$`````````````$@```-<!`````````````!(```#3
M```````````````2````%P(`````````````$@```.D"`````````````!(`
M``#Z`0`````````````2````=@``````````````$@```(H"````````````
M`!(```#W`@`````````````A````7@(`````````````$@```+<`````````
M`````!(````K`0`````````````2````+```````````````(````/@"````
M`````````!$````(`@`````````````2````:`(`````````````$@```!X"
M`````````````!(```"@`P``7)`````````0`!<`C`,``$DM``#`````$@`-
M`,0#``!])@``^`0``!(`#0#2`0``&14``,P!```2``T`4@,``&4=```$````
M$@`-`&,#``!(D````````!``%P!0!```:1T``*`!```2``T`C@0``'4K``#4
M`0``$@`-`#P$``!(D````````!``%P"K`P``"1\``!@````2``T`T0,``*$X
M``#8````$@`-`.D#``!0.@``!````!$`#P`8!```7)`````````0`!<`'00`
M`%R0````````$``7`$@$``!]'```/````!(`#0!=!```G24``.`````2``T`
M;P0``,DC``!@````$@`-`'T$```I)```2````!(`#0#<`P```)`````````0
M`!8`N`,``"$?```,`0``$@`-`)@#``!(D````````!``%@`.!```1)````0`
M```1`!8`X@,``.46````````$@`-`(4$```M.```=````!(`#0#>`P```)``
M```````@`!8`<0,``(TE```0````$@`-`)\#``!<D````````!``%P#X`P``
MN1P``*P````2``T`,@0``'DY``"^````$@`-`"4$```M(```G`,``!(`#0``
M7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y
M<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P
M97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G
M<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E
M<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W
M6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!0
M97)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?
M7V-X85]F:6YA;&EZ90!R96%D`'-T<F-H<@!G971P:60`7U]M96UM;W9E7V-H
M:P!?7VQI8F-?<W1A<G1?;6%I;@!?7V9P<FEN=&9?8VAK`'-T<F-M<`!O<&5N
M-C0`=6YL:6YK`'-T<G1O:P!M96US970`<W1R;F-M<`!G971U:60`;65M8VAR
M`&-L;W-E9&ER`'-T<G-T<@!R;61I<@!S=')L96X`<W1R9'5P`%]?;65M8W!Y
M7V-H:P!M96UC;7``<F5A;&QO8P!R96%D9&ER-C0`86)O<G0`7U]S<')I;G1F
M7V-H:P!S=&1E<G(`;65M8W!Y`'-T<G)C:'(`;'-T870V-`!O<&5N9&ER`&QS
M965K-C0`7U]V9G!R:6YT9E]C:&L`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`')E
M861L:6YK`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O+C4N,S@`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U
M<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S
M96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D
M871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN
M86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R
M+C,T``````````(``P`"``(``@`"``$``@`"``(``@`$``(``0`%``(``0`"
M``$``@`"``(`!0`"``(``0`!``$``0`"``(``@`!``(``0`"``(``@`"``$`
M`0`"``(``@`!``$``@`!``(``@`!``$``@`"``$``0`!``$``@`!``(``@`"
M``$``@`"``(``0`!``$``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0`^
M`P``$````"`````4:6D-```$`*0$`````````0`#`#0#```0`````````+.1
ME@8```4`K@0``!````"TD98&```#`+D$```0````%&EI#0```@"D!```````
M`+B-```7````O(T``!<```#PCP``%P````20```7````%)```!<````8D```
M%P```""0```7````))```!<````HD```%P```"R0```7````,)```!<````X
MD```%P```#R0```7````1)```!<```#(CP``%08``,R/```5"0``T(\``!4.
M``#4CP``%1```-B/```5'0``W(\``!,?``#@CP``%2$``.2/```5*P``Z(\`
M`!4O``#LCP``%3D``/2/```50@``^(\``!5(``#\CP``%4D``-2.```6`P``
MV(X``!8$``#<C@``%@4``.".```6!@``Y(X``!8(``#HC@``%@H``.R.```6
M"P``\(X``!8,``#TC@``%@T``/B.```6#P``_(X``!81````CP``%A(```2/
M```6$P``"(\``!84```,CP``%A4``!"/```6%@``%(\``!87```8CP``%A@`
M`!R/```6&0``((\``!8:```DCP``%AL``"B/```6'```+(\``!8>```PCP``
M%B```#2/```6(@``.(\``!8C```\CP``%B0``$"/```6)0``1(\``!8F``!(
MCP``%B<``$R/```6*```4(\``!8I``!4CP``%BH``%B/```6*P``7(\``!8L
M``!@CP``%BT``&2/```6+@``:(\``!8P``!LCP``%C$``'"/```6,@``=(\`
M`!8S``!XCP``%C0``'R/```6-0``@(\``!8V``"$CP``%C<``(B/```6.```
MC(\``!8Z``"0CP``%CL``)2/```6/```F(\``!8]``"<CP``%CX``*"/```6
M/P``I(\``!9```"HCP``%D$``*R/```60P``L(\``!9%``"TCP``%D8``+B/
M```61P``O(\``!9*``#`CP``%DL``,2/```63```"$`MZ4`!`.L(@+WH!.`M
MY03@G^4.X(_@"/"^Y:!\````QH_B!\J,XJ#\O.4`QH_B!\J,XIC\O.4`QH_B
M!\J,XI#\O.4`QH_B!\J,XHC\O.4`QH_B!\J,XH#\O.4`QH_B!\J,XGC\O.4`
MQH_B!\J,XG#\O.4`QH_B!\J,XFC\O.5X1_WG`,:/X@?*C.)<_+SE`,:/X@?*
MC.)4_+SE`,:/X@?*C.),_+SE`,:/X@?*C.)$_+SE`,:/X@?*C.(\_+SE`,:/
MX@?*C.(T_+SE`,:/X@?*C.(L_+SE>$?]YP#&C^('RHSB(/R\Y0#&C^('RHSB
M&/R\Y7A'_><`QH_B!\J,X@S\O.4`QH_B!\J,X@3\O.4`QH_B!\J,XOS[O.4`
MQH_B!\J,XO3[O.4`QH_B!\J,XNS[O.4`QH_B!\J,XN3[O.4`QH_B!\J,XMS[
MO.4`QH_B!\J,XM3[O.4`QH_B!\J,XLS[O.4`QH_B!\J,XL3[O.4`QH_B!\J,
MXKS[O.4`QH_B!\J,XK3[O.4`QH_B!\J,XJS[O.4`QH_B!\J,XJ3[O.4`QH_B
M!\J,XIS[O.4`QH_B!\J,XI3[O.4`QH_B!\J,XHS[O.4`QH_B!\J,XH3[O.4`
MQH_B!\J,XGS[O.4`QH_B!\J,XG3[O.4`QH_B!\J,XFS[O.4`QH_B!\J,XF3[
MO.4`QH_B!\J,XES[O.4`QH_B!\J,XE3[O.4`QH_B!\J,XDS[O.4`QH_B!\J,
MXD3[O.5X1_WG`,:/X@?*C.(X^[SE`,:/X@?*C.(P^[SE`,:/X@?*C.(H^[SE
M`,:/X@?*C.(@^[SE`,:/X@?*C.(8^[SE`,:/X@?*C.(0^[SE`,:/X@?*C.((
M^[SE`,:/X@?*C.(`^[SE`,:/X@?*C.+X^KSE`,:/X@?*C.+P^KSE`,:/X@?*
MC.+H^KSE`,:/X@?*C.+@^KSE`,:/X@?*C.+8^KSE`,:/X@?*C.+0^KSE`,:/
MX@?*C.+(^KSE`,:/X@?*C.+`^KSE`,:/X@?*C.*X^KSE`,:/X@?*C.*P^KSE
M<+5>38JP7DM]1%Y,S>D&$`:I!9('J`6J?$3K6!MH"9-/\``#__=:[U=*6$NB
M6`.2$4;C6`23&$8"\'+Z5$OC6!UX`"UCT!WN<"]*2P>8>T0;:,4<!#"P\8!/
MTEB2^,XS0_`#`X+XSC-TTH``__?Z[DA)24H#1GE$!IQZ1`EH4&`@:)E@14D'
MFGE$V6!$20$J&&!Y1%E@9=TA'03K@@X#\0P,4?@$2TSX!$^.1?G1T1P\3``@
M`)`J1GQ$0_@A`#I)X&AY1/_W3N\`*#'0-TT(KGU$Z&C_]Z+N!$8U2#%&>$0`
M\/+X0+,S2WM$V&C_]VCN__<L[S!*(DMZ1--8&F@)FUI`3_```S+1($8*L'"]
M__>>[BI*>D308#"S__=&[A9+'>YP+WM$&VC36(/XKE:,Y^!H__=.[\GGJ&@0
ML0'P>/O1YQ](,49X1`#POOBH8``HR=#SYQM+'$AX1.-8`Y,91O_WVNX$(:/G
M`2#_]ZSN__<V[@"_<GH``)QY``"D>0``"`$``)1Y```D`0``+`$``!`!``"R
M>@``MGH``&`H``!2*```>'H``#,&``!@>@``KB4``$AZ``"T>```''H``.(D
M```@`0``S"8``$_P``M/\``.`KQJ1@2T`;3?^!B@!:.:1$_P``,(M`1(6O@`
M`/_WENW_]_CNN'<``"@!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$C___J
MH'<``!P!```&2`=+!TIX1'M$>D2#0@/0!4O36`.Q&$=P1P"_`GD```!Y``!^
M=P``!`$```A("4MX1`E*>T0;&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`O]AX
M``#4>```4'<``#`!```(M0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W3.W_
M][__!DL!(GM$&G`(O:)X```@=P````$``$YX``"">```Q.<`ORWI^$.`1A]+
M>T0`*#;0'DJ;6-/X`)"Y\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.
M1BI&048@1O_W:NX0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK
M^=&EZP@%X>>FZPD&`34L1+80/F`@1KWH^(,$1N?G3$;EY]QV```T`0``%TH8
M2WI$$+4$1IRPTUAI1AMH&Y-/\``#__<0[:"Y!)L#]'!#L_4@3QB_L_6`3PW0
M#4H,2WI$TU@::!N;6D!/\``#"]$<L!"]`"#QYP(A($;_]_;ML/J`\$`)Z>?_
M]Q3M5'8```@!```D=@``-DHW2WI$\+6?L--8&V@=DT_P``,0L0-X!$9;N3%*
M,$MZ1--8&F@=FUI`3_```U/1'[#PO?_W/.T%1@`H[M`H1O_WVNT`*#;0PWP`
M\1,&+BL"T7-X`"ORT,-\+BLRT"!&__=6[0=&,$;_]U+M!T0"-SA&__<J[1Q+
M.D8"(7M$`98`E`9&__=B[0*I,$;_]]3L`3`P1@70!IL#]'!#L_6`3Q?0__?0
M[#!&__>&["A&__>D[0`HR-$H1O_WO.T@1O_WCNRKYW-X+BO)T;-X`"NVT,7G
M__>5_^;G__>@[.AU```(`0``S'4``(PA``!:2EM+>D0MZ?!/#$:#L`5&TUC?
M^&"!&V@!DT_P``,+>/A$/2L(OP$T($;_]_SL:48&1BA&__?R_H%&`"A4T/_W
M\NR&0D?93$L`GUCX`X"_`"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KY
MT5L;L!S8^`!@&$3_][#L\%'HL=CX`#`H1ME9$/@!.PMP/2L8OP`K"=!*'!#X
M`3L11@+X`3L`*QB_/2OVT0I&/2,+<!3X`3L"^`$_`"OYT2]*+$MZ1--8&F@!
MFUI`3_```TK1`["]Z/"/"?'_.13X`3L)^`$_`"OYT>GG(TM8^`.`V/@`<#MH
MF[,[1E/X!"])1@GQ`0D`*OC1`S%/ZH$+'$M[1!IHPKE81@$B&F#_]V#L@D8`
M*,O0.49/ZHD'6T8Z1O_WQNO(^`"@S?@`D`GQ`0D`(TKX*3"$YUE&.$;_]PSL
M@D;(^````"BQT$_JB0?KYYE&3_`("]+G__?DZP"__'0```@!``#@=```-`$`
M`$!T``!V=0``+>GP00]&+$DL2ZWU@%UY1(*P!D8-]8!0!#`-\00(RUA`]O]R
M048;:`-@3_```R1(>$3_]^CK!!X'W0*M8QX%ZP,,'/@$+.JYV[D92QWN<`\Z
M1C%&>T0;:,!8__?.ZQE*#?6`415+!#%Z1--8&F@+:%I`3_```QC1#?6`70*P
MO>CP@1Q&(D8O(4!&__=F[``HV]`(2!WN<%\C1D)&>$0`:#%&*%C_]W;LV>?_
M]X#K`+\\=```]',``&YS```(`0``<!\``!1S```PM1WN<$\22@])A;`12'I$
M>40):!!+`"5[1!)88%@/20.2>43_]P3L"$D-2WE$"6@,2GM$>D1@6`M)`95Y
M1`"3__<@[`6P,+VX<P``G',``*9R```,`0``=%\``,8>``"V(0``+0\``,@>
M```*2H*P"DD=[G#/>D0&2`E+>$0`:%)8>T0'25SX``!Y1`&2`K#_]\R[3',`
M`#YR```,`0``"E\``%X>```E2O"U)4MZ1*WU`%V'L`WU`%$#K--8%#$-]8!6
M&V@+8$_P``/_]WCK'4H"(1U+$#9Z1,WI``)[1"!&0?(!`O_WENL@1D_T@%(Q
M1O_W).L$'KB_`"4,VV<<.$;_]T;K!48PL3M&,48B1O_W&NL`(RM5#4H-]0!1
M"4L4,7I$TU@::`MH6D!/\``#!-$H1@WU`%T'L/"]__?2Z@9R```(`0``4!X`
M`#X>``"2<0``__>HOUM*+>GP3P9&6DMZ1*WUA%V!L%E(#?6#50WQ$`C36`Q&
M>$1!1APU&V@K8$_P``/_]R/]+R$%1C!&__<NZ\"Q3T@Q1GA$__<*_C!&34H-
M]8-12$L<,7I$TU@::`MH6D!/\``#0/"#@`WUA%T!L+WH\(\@1O_WANI#27E$
M__=JZP1&`"C<T"-X#?&`"M_X_)"J\00'^40`*TC0);$A1BA&__<>ZKBS($;_
M]^SJ0QXC1(-&G$(^OR,8`"%@'`/3"N"80AEP`]`3^`$M+RKXT"!&__?8ZH-&
M,$;_]]3J6$0!,+#U@%^LTBE(`B%+1D_T@%)X1`"4S>D!!CA&__?@ZD%&.$;_
M]U+J,+E:^&`\`_1P0[/U`$\7T!Y)`"!Y1/_W&NL$1@`HC-`C>``KMM'5L2MX
M+BL$T!A,3_`!"WQ$R^=K>``KZ-#VYP$A.$;_]_SJ`"CAT1%(.49X1/_W@?TX
M1O_W$.ISYPY,3_`!"WQ$L^?_]P[J4G$```@!``"X'0``HAT```AQ``!\'0``
M9AT``!(=``#<'```G!P``)`<``!L'```$+4O(01&__?:Z@"Q1!P@1KWH$$#_
M]^*Y.TKPM3M+>D2M]8!=@[`-]8!1TU@$,1MH"V!/\``#`"@\T`-X!48`*SC0
M__=.ZD(<!$:R]8!?1]@!KRE&.$;_]Y[I8QX[1)]""](X&0WQ!0(`(0+@D$(!
M<`/0$/@!/2\K^-`O(3A&__>>ZGBSN$*$OP`C`W`X1O_WJ.D?2@WU@%$<2P0Q
M>D336!IH"VA:0$_P``,KT0WU@%T#L/"]%TH-]8!1%$L$,7I$TU@::`MH6D!/
M\``#&M$22'A$#?6`70.PO>CP0/_W?KD`(-;G#4H-]8!1"$L$,7I$TU@::`MH
M6D!/\``#`M$(2'A$YN?_]W+IGF\```@!```@;P``_FX``&0;``#.;@``-!L`
M`,Q*S4MZ1'"US$Z"L,Q-TUA^1&Q&?40;:`&33_```R%&,$;_]\?[L+'&2P"8
MZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WL?L`*.C1O$Y^
M1"%&,$;_]ZG[L+&W2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1
M(48P1O_WD_L`*.C1KDY^1"%&,$;_]XO[L+&H2P"8ZU@9:`'K@`-::$'X("``
M*N_0!#-::$/X!"L`*OK1(48P1O_W=?L`*.C1H$Y^1"%&,$;_]VW[L+&92P"8
MZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W5_L`*.C1DDY^
M1"%&,$;_]T_[L+&*2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1
M(48P1O_W.?L`*.C1A$Y^1"%&,$;_]S'[L+%[2P"8ZU@9:`'K@`-::$'X("``
M*N_0!#-::$/X!"L`*OK1(48P1O_W&_L`*.C1=DY^1"%&,$;_]Q/[L+%L2P"8
MZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W_?H`*.C1:$Y^
M1"%&,$;_]_7ZL+%=2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1
M(48P1O_WW_H`*.C16DY^1"%&,$;_]]?ZL+%.2P"8ZU@9:`'K@`-::$'X("``
M*N_0!#-::$/X!"L`*OK1(48P1O_WP?H`*.C13$Y^1"%&,$;_][GZL+$_2P"8
MZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WH_H`*.C1/DY^
M1"%&,$;_]YOZL+$P2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1
M(48P1O_WA?H`*.C1,$@A1GA$__=^^@%&&+$M2'A$__=J^RQ((49X1/_W<_H!
M1ABQ*DAX1/_W7_LI2"%&>$3_]VCZ`4:PL29(>$3_]U3[)4H12WI$TU@::`&;
M6D!/\``#%=$A22)(>41X1`*PO>AP0/_W0;L?2"%&>$3_]TKZ`48`*.30'$AX
M1/_W-?O?Y_[WRN^4;@``"`$``#`;``"$;@``-`$``/0:``#`&@``D!H``%P:
M```P&@``D!D``,09``"4&0``9!D``*P8``#V&```TA@``/08``#\&```_A@`
M`"H8``"D:P``7!H``%X8``#2&```7!@``!-*%$MZ1`"U$TB#L--8>$1I1AMH
M`9-/\``#__?]^4"Q`'@`*!B_,"@,OP$@`""`\`$`"DH'2WI$TU@::`&;6D!/
M\``#`M$#L%WX!/O^]V[O^&H```@!``#:%P``QFH```^TW_@TP`"U#$K\1(.P
M!*L+20Q(7/@"('E$$F@!DD_P``)3^`0K`),(6`(A`&C^]ZKO_R#^][[ODFH`
M``@!``"$:@``&`$``"WI\$<"(3],K?6`/0`BAK!\1`WU@#4`(Q0U@$8`D3I)
M85@):"E@3_```?[W:N\!.&'Q``?Z%X#J`@.;&INR4T";&F+K`@+&&F?K`@<`
M+TO;3_`("<#R`0D#K0`A,D8[1D!&`)'^]TSOL?'_/PB_L/'_/T'02D8I1D!&
M_O>^[D,<-M`'*";9"#@L&"/2W_A\H/I$`N`!/*Q"'-,((E%&($;^]]SN`"CU
MT60;H!E'Z^1Q%TH-]8`T%$L4-'I$TU@::"-H6D!/\``#&M$-]8`]!K"]Z/"'
MMO6`-F?Q``>W\?\_"+\6]8`_N-%/\/\P`4;?YPA(>$3_]V#_!TAX1/_W7/_^
M]\#N1&H```@!```$:P``FFD``-H6``#"%@``"+7^]W+N_O=D[@"Q`&@(O2Y*
M+TMZ1/"U+DZ'L`5&TUA^1`2I,$8;:`633_```__W$?D0L0-X!$:+N2=*)$MZ
M1--8&F@%FUI`3_```SS1(T@I1GA$!["]Z/!`__?MN2E&_O<>[EBQ'DH92WI$
MTU@::`6;6D!/\``#)M$'L/"]*$;^]^SN!T8@1O[WZ.X'1`(W.$;^]\#N$TL3
M23I&>T0"E'E$`)4!D0(A!$;^]_;N#TH'2WI$TU@::`6;6D!/\``#!+\A1C!&
MQ=#^]T[N)&D```@!``"<%@``^F@``&H6``#.:```.!4``#`5``"&:```+>GP
M3]_X;"2_L-_X;!1Z1-_X:%1Y1"2O"))]1-_X8"0%\0P#!Y`%\1@,*JPP-29&
M#?&<"8I8#?$H"!)H/9)/\``"D^@'`(?H!P"\Z`\`#\:<Z`,`AN@#`)7H!P")
MZ`<`W_@@!$%&>$3_]WSX(+$#>`5&`"M`\'Z!_O>^[?[WL.T`*`#PKX`&:``N
M`/"K@#!&_O=L[D(``O$!"E!&_O="[@5&,'@`*`#P=X'31@F5W_C8D_E$4D9+
M1@"0`B$H1@(U_O=R[M-%%O@!#UM&.+]31J/K"@*J\0(*`C*JZP,*FD(LOY)$
MFD0`*.31Z$AX1`+@5/@$#XBQ04;_]S3X!48`*/;0`W@`*_/0__=R^``H[]`H
M1O[WK.T$1HBY5_@$2W2Q(W@`*P#P$($@1O_W8?@`*//0($;^]YKM!$8`*.W0
M($;^]Q3N"9T&1BA&_O<0[@9$!O($1C!&_O?F[<U+!T8R1GM$`I/+2P(A`Y5[
M1`&3RDL`E'M$_O<8[D_TX'$X1O[W*.X!,`71_O<*[@%H$2E`\..`048X1O[W
M2NT$1@`H/-"^20B8!YN^2D!8`B$;:'I$`)<`:/[W*NX`);I*L$MZ1--8&F@]
MFUI`3_```T#P3($H1C^PO>CPC_[W2.T&1@`H0/"T@%GX!`M8L4%&_O>Z_P`H
M]]`#>``K[M%9^`0+`"CST:E.#2!/\`T+_O>,[7Y$!48)D-I&4R!)YPZ;`_1P
M0[/U@$^\T1"=_O?F[(5"M]$.F\/S"`.S]>!_L=$P1O[W<NT%1IE(049X1/[W
MB_\!1@`H`/"C@`>;&&C_]T?Z@T8`*`#PFX!81O[W@.V!1@,H$-F/200X6$1Y
M1/[WINQ(N;GQ!`\`\-F`V409^`4\+RL`\-.`ATA!1GA$_O=C_R"Q`W@P*QB_
M`"L&T5A&`"'^]S3M@$8`*'71?TF`2'E$W_@`HGA$W_C\D?_W/OC?^/B!_O=`
M[7U+?DH"(7M$S>D`<WQ+>D0"D"A&`Y)[1#)&^D3Y1/A$_O=8[1/@_O=0[0-H
M$2L5T?[W)NT!-(1&4T8R1@(A*$;-Z0-)S>D!C`"7_O=$[4_TX'$H1O[W4NT!
M,.30.$;^]W#L:$@I1GA$__<$^"A&__?M_3CG'$;XYO[W#NU"``+Q`0J@YE!*
M")@'FX!8&VA>2LWI`'$"(7I$`&C^]T[M(>?_]]3]64I!2WI$TU@::#V;6D!/
M\``#;=$H1C^PO>CP3_[W:+P)E:;F!YO3^`"P8.?_]R;]@4:Q\0`*@]NP\0H"
M3_``"VKQ``-`1LWX`+#^]YCL,*D&(D!&!Y'^]P[L!YD&*$G1,)I/](9#Q/)!
M,YI"?_1HKXJ(1/)(4YI"?_1BK[GQ,@)`1FKQ``,RK,WX`+#^]W;L0$8H(B%&
M_O?NZR@H*M$S2S)&,TDH1GM$S>D`<S%+>40"E`.1>T0"(8WX\+#^][CL>N<'
MF]/X!)"Y\0`//_0FKTA&_O>0[`,H?_8@KR9)!#A(1'E$_O>TZP`H"+_+1A7G
M_O<&["%(>$3_]YS\.F@``#1H``!N:0``"`$``%X4```R%0``E!0``)@4``""
M$P``>A0``!@!``".%```BF8``,X3``!(%```(!0``)P2``!8%```<A(``.83
M``",%```^A$``!(2``":%```VA,``(H1``"6$@``S&0``,X0``!6$P``B!(`
M`$82```Z$@``9$EE2GE$<+5:2X*P'>YP3XI8;D9A2#%&$F@!DD_P``)[1!MH
M>$3E6)7X:#"%^&DP_O<<_A"Q`W@Q*WS0__<\^DU+>T0;:.5854DH1@,C`2)Y
M1/[W^.L%1G"Q`FE'2WM$&V@1:$]*X%AZ1/[WL.LK:1EHBVA;`FO404D#(P$B
M>40):&!82$EY1/[WW.L%1GBQ1D@Q1GA$_O?I_0)&`"A.T#A+*6E[1!MH"6C@
M6/[WCNLU2P$B/DE[1!MH>43E6"A&_O?JZSM*`48H1GI$.DW^]W[K+DLY2'U$
M>T0;:``B>$0Q1N-8@_AI(/[WP/T$1JA@L+%/].!Q($;^]^[K0AP#1A$H&+\!
M*BS8+4HC2WI$TU@::`&;6D!/\``#(-$"L'"]:&C_]_'\!$:H8``HX=$E2'A$
M_O?$ZT-X`"N%T'[G(DLJ:7M$$&A;:!EH_O=#_Z_G#TM[1!MHX%C^]]#KC.?^
M]Q#K&DDB1AI(>41X1$EH"6C^]Z3K1&0``")D```&9```YF,``,!C``"N8P``
MC&,``!)C``!,8P``"`$``/P/``"@$0``C!$``'81``!$#P``1A$``$X1``#^
M8P``[@X``$1B``#P$```DF,``&QC``#:$```*4HJ2WI$,+4$1BE(@[#36&E&
M>$0;:`&33_```_[W//UPL0-X`"L8OS`K#+\!(P`C@_`!`P`L#+\`(P/P`0-;
MN1Q*&DMZ1--8&F@!FUI`3_```R?1`[`PO2-X`"OPT"!&__>Z^"\A!4;^]XCK
M`+%%'"A&_O>6ZA!)!")Y1/[WENL`*-W1#4H)2WI$TU@::`&;6D!/\``#!=$@
M1@.PO>@P0/[W=KW^]X+J>&$```@!``!6#@``.&$``+(.``#T8```+>GP3P-&
MW_@02JWU*WT#\8`'W_@(.GQ$"*D`)@*0"D9`,+Q&XU@;:*F33_```U#I`G16
M8-9@$#(_ND+X$'PC"B4"`_1_0P@P0^H48P7T?P5#Z@1C8$5#Z@4#0O@(/.;1
MW>DB@@JL)IL-\8@)`),DJ":M`?4"<P.0($8$E<WI!4$-:,WX')"11MWXE.#=
M^)S`"9_=^"RP))[=^"B@`)D!DP'@DD:;1@"1`"/0Z0X44/@(+T-G44"!Z@@!
ML$9#:&E``)Y51EQ`A.H)!/%&?$#F1D_JT7Q)&$SJ1`P!G$'J#`%?1D_P``R$
M0@%GVM$#FP*8W>D%01UH!)O0Z0%[&V@#D]#I`SI/ZIL.T/@`P`IH(6A.ZH-^
MA&E']ID3Q?:"(P"4!&K2&$_JW&`!E$#J1Q`2&0"<0.I,$-WX')""&(KJ!`!.
MZHM^`.H+`-WX,(!@0-GX`&`2&$_JG`F*Z@X`R1A)ZH=Y`.H,`$GJC'D)&8#J
M"@`.GP@8CNH)`1CK`P@10`#K\F`8ZPH(@>H.`4_JL@(8ZP$!_Q@7ZPX(`>OP
M9XGJ`@'=^$#@`4!/ZK``@>H)`1CK`0$>ZP,.'NL)"0'K]VZ"Z@`!W?A(@#E`
M3^JW!U%`&>L!`1CK`P@8ZP()@.H'`MWX4(`"Z@X"`>O^84)`3^J^#AGK`@(8
MZP,(&.L`"0+K\6"'Z@X"W?A8@`I`3^JQ`7I`&>L"`ACK`P@8ZP<)`NOP9X[J
M`0+=^&"``D!/ZK``@NH.`AGK`@(8ZP,(&.L."0+K]VZ!Z@`"W?AH@#I`3^JW
M!TI`&>L"`ACK`P@8ZP$)`NO^88#J!P+=^'"``NH.`D_JO@Y"0!GK`@(8ZP,(
M&.L`"0+K\6"'Z@X"W?AX@`I`3^JQ`7I`&>L"`ACK`P@8ZP<)`NOP9X[J`0+=
M^("``D!/ZK``@NH.`@.<&>L"`ACK`P@8ZPX.`NOW:('J``(Z0$_JMP=*0![K
M`@+V&'88@.H'`0'J"`$"Z_AB04!/ZK@(<1CM&"T8`>OR8(?J"`$10$_JL@*(
MZ@(&>4!I&`9`*)WD&`'K\&&&Z@@&3^JP`.09I!F"Z@`'[1@/0!7K"`8JG03K
M\6170$_JL0'V&8#J`0[M&*\8#NH$#BR=3^JT`H[J``X&Z_1F%^L.!('J`@?M
M&#=`+1@NF$]`!.OV9.\93^JV!L,8,)U;&(+J!@$A0`?K]&Y10$_JM`18&$[V
MH3/&]MEC,ID5ZP,(`.O^8!CK`@B&Z@0"@NH.`D_JO@48ZP((A.H%#LH8-)\(
MZ_!ACNH`#I(93^JP`!+K#@(VGO\8A>H`#@+K\6*.Z@$./!E/ZK$!%.L.!#B?
M]AB`Z@$.!.OR9([J`@YU&4_JL@(5ZPX%.IZ!Z@(._QB.Z@0./Q@%Z_1@%^L.
M!T_JM`06ZP,./)T>ZP$.!^OP88+J!`='0$_JL``>ZP<.[Q@^GK\8#NOQ8H3J
M``Z.Z@$.3^JQ`1?K#@<6ZP,.0)T>ZP0.!^OR9(#J`0=70$_JL@(>ZP<.[QA"
MGC\8#NOT8('J`@Z.Z@0.3^JT!!?K#@=$G8+J!`[V&`?K\&>.Z@`.=AA/ZK``
M%NL.!D:9A.H`#NT8!NOW9H[J!PZM&$_JMP<5ZPX%2)K)&(#J!PX%Z_9ECNH&
M#@P93^JV!A3K#@1*F=(8A^H&#@3K]62.Z@4.$!A/ZK4%$.L.`$R:ANH%#LD8
M`.OT8([J!`[)&4_JM`01ZPX!3I^%Z@0.TA@!Z_!ACNH`#I(93^JP`!+K#@)0
MGO\8A.H`#@+K\6*.Z@$.?1E/ZK$!%>L.!5*?]AB`Z@$.CNH"#C09%.L.!`7K
M\F87ZP,.3^JR`E2='NL`#H'J`@`$Z_9D<$`>ZP`.3^JV`.T8@NH`!FD85IUF
M0`[K]&Z)&4_JM`3K&%B=FQB`Z@0"@NH.`D_JO@>:&$OVW$/(]AMS`>O^8>T8
M1.H'#EJ>*!@.Z@$.!.H'!4[J!0X"Z_%B$.L.#D_JL0'P&%R=`!E'Z@$$#NOR
M9A1`!^H!#D_JL@)$Z@X$`>H"""08[1A!Z@(`%>L'#C!`!.OV95Z<0.H(`$_J
MM@80ZPX.X!@.Z_5D0!A"Z@8!`NH&#BE`8)]!Z@X!3^JU!0D8`>OT8/\81NH%
M`0;J!0ZZ&"%`8I]/ZK0$0>H.`07J!`B)&/\81>H$`A?K!@X"0&2?`>OP84+J
M"`)/ZK``$NL.`O\8!.H`#GT9`NOQ9T3J``)FG@I`3^JQ`4+J#@+=^*#A51GR
M&!(90.H!!$_JMP8%Z_=E/$``Z@$'/$-!Z@8'HA@>ZP,$)!@!Z@8.:I@O0`+K
M]6)'Z@X'3^JU!3P91NH%!\`8!.OR9`;J!0Y`&!=`3^JR`6R:1^H.!S\81>H!
M`-(8($"2&0?K]&8%Z@$'3^JT!#A#0>H$!X`8;IH!Z@0.-T#2&`#K]F!5&7":
M1^H.!T_JM@9_&=(851@'Z_!A1.H&!P3J!@YRF@=`1^H.!T_JL`!]&=(8$AE&
MZ@`$!NH`!PQ`/$,%Z_%EI!ATFD_JL0$$Z_5DTAA`Z@$'`.H!#I89+T!VFD?J
M#@=/ZK4%OQG2&!88!^OT8$'J!0<!Z@4.>)HG0$?J#@=/ZK0$OQE%Z@0&TA@&
M0%(8!^OP807J!`=/ZK``/D,"G[88`"($Z@`.!NOQ9GI@^F!ZFM(851D`(GIA
M^F%$Z@`'?)H/0$?J#@=/ZK$!?QG2&$#J`04'Z_9G$NL$#C5`3^JV!'Z:`.H!
M!C5#`>H$!A7K#@73&!L80>H$`#A`@)HP0P7K]V7`&$SRUA/,]F(C3^JW!]88
M@IIV&(3J!P%I0`#K]6!V&$_JM072&(?J!0$4&82:04`&Z_!F9!A/ZK``TAB%
MZ@`!UQF&F@3K]F1Q0'\83^JV!M$8B)I)&0?K]&6`Z@8'9T!/ZK0$R1G7&#\8
MBIJ&Z@0``>OU86A`3^JU!3\8T!B`&8R:!^OQ9H3J!0=/0$_JL0'`&=<8/QF.
MFH7J`00`Z_9@=$`_&4_JM@36&)":=AD'Z_!E@>H$!T=`3^JP`/89UQA_&)*:
M!NOU883J``9N0$_JM06_&=88-AF4F@?K\62`Z@4'3T!/ZK$!]AG7&#\8EIH&
MZ_1@A>H!!F9`3^JT!+\9UAAV&9B:!^OP98'J!`='0$_JL`#V&=<8?QB:F@;K
M]6&$Z@`&;D!/ZK4%OQG6&#89G)H'Z_%D@.H%!T]`3^JQ`?89UQ@_&)Z:!NOT
M8(7J`09F0$_JM`2_&=88=AF@F@?K\&6!Z@0'1T!/ZK``]AG2&%<8!NOU8:*:
MA.H`!FY`3^JU!;\9TA@6&0?K\62`Z@4'I)I/0$_JL0'W&0*>!^OT9](8$!@*
MZ[<",F&FFH7J`09F0$_JM`2`&=,8@>H$`@#K]V!Z0!/K#`,"GUL9FQ@0ZPL"
M`^OP8P"8.V`!FR08NF`,2LD8`"-[8@E+>D2\83EBTU@::*F;6D!/\``#`]$-
M]2M]O>CPC_WW;.T`OZ9@```(`0``QE8```BU@"#]][;MG^T.>P`B@F>`[0![
MG^T->X#M`GN?[0U[@.T$>Y_M#7N`[09[G^T->X#M"'N?[0U[@.T*>X#M#'L(
MO0"_`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````
M````````+>GX0P5&%D:`:@`C#$;W%]7I#"$`Z\8,A$7H:G/K```"T@$R0?$`
M`:AO!?$X",7I"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D7=IO%`"4_JF19W'`3K
MAQ<A1D-&!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#
M^`0LZ]$,1BA&__=M^KQ"X=&IZX86,D8Y1D!&_?>N[*YGO>CX@\#Q0`<%\3@(
MMT)`1*B_-T8A1CI&_?>@[*MO.T2K9T`K[-$H1O8;/$3_]TOZM^<G1M[G+>GP
M00'Q.`<,1HMJ!48*:Y/Z@_C#\\4#%KI9'(`B."GZ5$7=P?%``G@8`"']]UCM
M($;_]RWZ.$8X(@`A_?=0[2!&Q.D<:/_W(_KC>"MP($9CB&MP(V@;"JMP(VCK
M<.-Z*W%CB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR(VGK<N-^*W-CBVMS
MHVD;"JMSHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP0?WW,KQX&,'Q.`(`
M(?WW$NW`YP"_`DM[1!MH_?=?O`"_QE4```A`+>D(@+WH`0`"`#X```!!````
M#````$$````1````00```"<```!!````-@```$$````#````00````8```!!
M````%0```$$````/````00````X```!!````)@```$$````3````00```"D`
M``!!`````@```$$````9````00````H```!!````"P```$$`````````````
M`"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E
M>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S
M```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?
M1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'
M3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!
M4E]'3$]"04Q?0TQ%04X`````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````
M<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S:&]R
M="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T
M96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI6
M15)324].`````#$N,#8Q````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`
M````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?
M<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)
M3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE
M.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E
M860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M
M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I
M;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA
M9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F
M("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F
M;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D
M8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I
M>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F
M<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@
M,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D
M:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E
M('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D
M:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO
M9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@
M>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@
M<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*
M<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R
M(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D17
M4B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@
M=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE
M9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ
M*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*
M:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY
M("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA
M;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B
M)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D[
M"FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M
M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E
M9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F
M:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D
M9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?
M<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92![
M"FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T
M.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H
M)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C
M86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D
M(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N
M86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN
M+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X
M=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T
M:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A
M8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@
M(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I
M<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH
M;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D
M8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[
M7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E
M;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,
M3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`'!E<FQX<VDN8P````!#04-(10``/@```$$````,````
M00```!$```!!````)P```$$````V````00````,```!!````!@```$$````5
M````00````\```!!````#@```$$````F````00```!,```!!````*0```$$`
M```"````00```!D```!!````"@```$$````+````00``````````````H)K_
M?P$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````W1<``)T7```!````)`,```$````T`P```0```#X#```,````
M#!(```T```!(.@``&0```+B-```;````!````!H```"\C0``'`````0```#U
M_O]OM`$```4```!0"0``!@```*`"```*````Q`0```L````0````%0``````
M```#````R(X```(```#H`0``%````!$````7````)!```!$```!,#P``$@``
M`-@````3````"````!X````(````^___;P$```C^__]O[`X``/___V\"````
M\/__;Q0.``#Z__]O#@``````````````````````````````````````````
M``````````````#`C0`````````````8$@``&!(``!@2```8$@``&!(``!@2
M```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(`
M`!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``
M&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8
M$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2
M```8$@``&!(``!@2```8$@``&!(``!@2```8$@``&!(``!@2```8$@``````
M`````````````````````````````````````````````````!D5````````
M````````````````!)````I005(N<&T*`````"@^``!`.P`````````\```$
M/```'#X``$@[```D/@````````@^```0/@```````#`^``!'0T,Z("A58G5N
M='4@,3,N,BXP+3EU8G5N='4Q*2`Q,RXR+C``03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````````"P````$````"````5`$``%0!```9```````````````!````````
M`!,````'`````@```'`!``!P`0``)```````````````!``````````F````
M!P````(```"4`0``E`$``"````````````````0`````````-````/;__V\"
M````M`$``+0!``#L````!0`````````$````!````#X````+`````@```*`"
M``"@`@``L`8```8````#````!````!````!&`````P````(```!0"0``4`D`
M`,0$``````````````$`````````3@```/___V\"````%`X``!0.``#6````
M!0`````````"`````@```%L```#^__]O`@```.P.``#L#@``8`````8````"
M````!`````````!J````"0````(```!,#P``3`\``-@````%``````````0`
M```(````<P````D```!"````)!```"00``#H`0``!0```!4````$````"```
M`'P````!````!@````P2```,$@``#```````````````!`````````!W````
M`0````8````8$@``&!(````#``````````````0````$````@@````$````&
M````&!4``!@5```P)0`````````````(`````````(@````!````!@```$@Z
M``!(.@``"```````````````!`````````".`````0````(```!0.@``4#H`
M`/1!``````````````0`````````E@````$``'""````1'P``$1\```(````
M#0`````````$`````````*$````!`````@```$Q\``!,?```!```````````
M````!`````````"K````#@````,```"XC0``N'T```0```````````````0`
M```$````MP````\````#````O(T``+Q]```$```````````````$````!```
M`,,````&`````P```,"-``#`?0``"`$```8`````````!`````@```#,````
M`0````,```#(C@``R'X``#@!``````````````0````$````T0````$````#
M`````)````"```!(```````````````$`````````-<````(`````P```$B0
M``!(@```%```````````````!`````````#<`````0```#``````````2(``
M`"4```````````````$````!````Y0````,``'```````````&V````S````
M```````````!``````````$````#``````````````"@@```]0``````````
+`````0``````````
